==> dl.php?src=linea21_1_7.zip: linea21/workshop/sup.php <==
<?php
/**
 * @package linea21.modules
 * @subpackage workshop
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

if(isset($_POST['id']))	$id=$_POST['id'];
if(isset($_GET['id']))	$id=$_GET['id'];

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->isSuperAdmin()) ReloadIndex('admin');
////////////

$link_det=$rub_link."&amp;todo=det&amp;id=".$id;

if(isset($_POST['valider'])) {
  $workshop_object = new workshop;
  $link_confirm="confirm.php?rub=".$rub."&todo=".$todo;
  $result=$workshop_object->DeleteWorkshop($id, $sql_object);
  if($result) header("Location: ".$link_confirm);
  else  system_error();
}

$req_det= SQL_getoneCompleteWorkshop($id);
$result=$sql_object->DBSelect($req_det);
if(count($result)>1) exit();
$workshop_denomination=FormatTitleh2($result[0]['workshop_denomination']);

?>
<div id="chemin">
<ul>
	<li><a href="index.php" class="chemin_home"><?php echo _t('way','home') ?></a></li>
	<li><a href="<?php echo $rub_link; ?>" id="chemin_<?php echo $rub; ?>" class="chemin_rub"><?php echo _t('menu','workshop')?></a></li>
	<li><span><?php echo formatnavTitle(_t('workshop','sup')." : ". $workshop_denomination); ?></span></li>
</ul>
</div>
<!--end barre haute -->
<?php
include_once(THEME_ADMIN_PATH."quickicons.php");
?>
<div class="contentcontainer"><?php
include_once(override($dir.'/menurub.php', THEME_ADMIN_PATH));
?>
<div id="content"><?php afflinkbar($todo,$id, $lang); ?> <?php echo "<h2>".$workshop_denomination."</h2>"; ?>
<form id="supworkshop" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
	<div class="info">
	<i class="icon-trash"></i> 
		<?php echo _t('workshop','sup_workshop_warning'); ?>
	</div>
	<div>
		<input name="id" type="hidden" value="<?php echo $id; ?>" />
		<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
		<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
		<?php echo cancel_button($rub_link."&amp;todo=det&amp;id=".$id); ?>
		<input name="valider" type="submit" value="<?php echo _t('btn','valid') ?>" class="button" id="valider" />
	</div>
</form>
</div>
<?php include_once(override($dir.'/help.php', THEME_ADMIN_PATH)); ?>
</div>

==> dl.php?src=linea21_1_8.zip: linea21/workshop/sup.php <==
<?php
/**
 * Workshop module - Delete workgroup page
 * 
 * Delete workgroup page
 * 
 * @package linea21\modules\workshop
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

if(isset($_POST['id']))	$id=$_POST['id'];
if(isset($_GET['id']))	$id=$_GET['id'];

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->isSuperAdmin()) ReloadIndex('admin');
////////////

$link_det=$rub_link."&amp;todo=det&amp;id=".$id;

if(isset($_POST['valider'])) {
  $workshop_object = new workshop;
  $link_confirm="confirm.php?rub=".$rub."&todo=".$todo;
  $result=$workshop_object->DeleteWorkshop($id, $sql_object);
  if($result) header("Location: ".$link_confirm);
  else  system_error();
}

$req_det= SQL_getoneCompleteWorkshop($id);
$result=$sql_object->DBSelect($req_det);

// Do record exists?
if(!isset($result[0]['workshop_denomination'])) redirect_to('@module_default');

$workshop_denomination=FormatTitleh2($result[0]['workshop_denomination']);

?>
<div id="chemin">
<ul>
	<li><a href="index.php" class="chemin_home"><?php echo _t('way','home') ?></a></li>
	<li><a href="<?php echo $rub_link; ?>" id="chemin_<?php echo $rub; ?>" class="chemin_rub"><?php echo _t('menu','workshop')?></a></li>
	<li><span><?php echo formatnavTitle(_t('workshop','sup')." : ". $workshop_denomination); ?></span></li>
</ul>
</div>
<!--end barre haute -->

<div class="contentcontainer"><?php
include_once(override($dir.'/menurub.php', THEME_ADMIN_PATH));
?>
<div id="content"><?php afflinkbar($todo,$id, $lang); ?> <?php echo "<h2>".$workshop_denomination."</h2>"; ?>
<form id="supworkshop" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
	<div class="info">
	<i class="icon-trash"></i>
		<?php echo _t('workshop','sup_workshop_warning'); ?>
	</div>
	<div>
		<input name="id" type="hidden" value="<?php echo $id; ?>" />
		<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
		<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
		<?php echo cancel_button($rub_link."&amp;todo=det&amp;id=".$id); ?>
		<input name="valider" type="submit" value="<?php echo _t('btn','valid') ?>" class="button" id="valider" />
	</div>
</form>
</div> <!-- closing #content -->
</div> <!-- closing .contentcontainer -->
